==> sigma-align_1.1.1.orig.tar.gz: sigma-1.1.1/src/printhelp.c <==
#include <stdio.h>
void printhelp() {
    printf("Sigma, version 1.1: simple greedy multiple alignment\n");
    printf("Copyright (C) 2006 Rahul Siddharthan <rsidd@imsc.res.in>\n");
    printf("Licensed under the GNU General Public License, version 2\n");
    printf("\n");
    printf("Usage: sigma [options] inputfile.fasta [inputfile2.fasta ...]\n");
    printf("\n");
    printf("Each fasta file may contain a single sequence or multiple sequences;\n");
    printf("all sequences will be aligned together.\n");
    printf("\n");
    printf("Options:\n");
    printf("  -A, --aligned_output \n");
    printf("     (aligned output; this is the default.  Compare the -F option.\n");
    printf("      -A and -F may both be specified, in either order.)\n");
    printf("  -B, --bgprobfile filename \n");
    printf("     (name of file containing background probabilities; each line\n");
    printf("      should contain either a single nucleotide or a dinucleotide\n");
    printf("      followed by a space and a count.  Counts will automatically be\n");
    printf("      normalised.  Trinucleotides and higher will be ignored.)\n");
    printf("  -b, --bgseqfile filename\n");
    printf("     (name of auxiliary file from which to read background sequences; \n");
    printf("      overridden by -B)\n");
    printf("  -C, --caps_only\n");
    printf("     (output sequence in uppercase only, as in output of some other\n");
    printf("      programs like ClustalW and MLagan.  Default is mixed-case,\n");
    printf("      where uppercase indicates aligned sequence, as in Dialign.)\n");
    printf("  -F, --fasta_output \n");
    printf("     (multi-fasta output; compare -A option.  Default is mixed-case;\n");
    printf("      for upper-case only, specify -C)\n");
    printf("  -l, --maxfraglength \n");
    printf("     (very long sequences are \"pre-fragmented\" into pieces of this \n");
    printf("      average length, or less, for efficiency; default 4000)\n");
    printf("  -n, --ncorrel \n");
    printf("     (background correlation order; 2=dinucleotide is the default,\n");
    printf("     1=single-site basecounts, 0=0.25 per base.  Higher than 2 not\n");
    printf("     implemented at present.)\n");
    printf("  -x, --significance \n");
    printf("     (set limit for how probable the match is by chance: the default \n");
    printf("      is 0.002, smaller=more stringent)\n");
    printf("  -h, --help\n");
    printf("     (display this help summary)\n");
}

==> sigma-align_1.1.3.orig.tar.gz: sigma-1.1.3/src/printhelp.c <==
#include <stdio.h>
void printhelp() {
    printf("Sigma, version 1.1.3: simple greedy multiple alignment\n");
    printf("Copyright (C) 2006-2009 Rahul Siddharthan <rsidd@imsc.res.in>\n");
    printf("Licensed under the GNU General Public License, version 2\n");
    printf("\n");
    printf("Usage: sigma [options] inputfile.fasta [inputfile2.fasta ...]\n");
    printf("\n");
    printf("Each fasta file may contain a single sequence or multiple sequences;\n");
    printf("all sequences will be aligned together.\n");
    printf("\n");
    printf("Options:\n");
    printf("  -A, --aligned_output \n");
    printf("     (aligned output; this is the default.  Compare the -F option.\n");
    printf("      -A and -F may both be specified, in either order.)\n");
    printf("  -B, --bgprobfile filename \n");
    printf("     (name of file containing background probabilities; each line\n");
    printf("      should contain either a single nucleotide or a dinucleotide\n");
    printf("      followed by a space and a count.  Counts will automatically be\n");
    printf("      normalised.  Trinucleotides and higher will be ignored.)\n");
    printf("  -b, --bgseqfile filename\n");
    printf("     (name of auxiliary file from which to read background sequences; \n");
    printf("      overridden by -B)\n");
    printf("  -C, --caps_only\n");
    printf("     (output sequence in uppercase only, as in output of some other\n");
    printf("      programs like ClustalW and MLagan.  Default is mixed-case,\n");
    printf("      where uppercase indicates aligned sequence, as in Dialign.)\n");
    printf("  -F, --fasta_output \n");
    printf("     (multi-fasta output; compare -A option.  Default is mixed-case;\n");
    printf("      for upper-case only, specify -C)\n");
    printf("  -n, --ncorrel \n");
    printf("     (background correlation order; 2=dinucleotide is the default,\n");
    printf("     1=single-site basecounts, 0=0.25 per base.  Higher than 2 not\n");
    printf("     implemented at present.)\n");
    printf("  -x, --significance \n");
    printf("     (set limit for how probable the match is by chance: the default \n");
    printf("      is 0.002, smaller=more stringent)\n");
    printf("  -h, --help\n");
    printf("     (display this help summary)\n");
}
